=== modified file 'local/in/DHISMIDP/src/org/hispindia/mobile/Compressor.java'
--- local/in/DHISMIDP/src/org/hispindia/mobile/Compressor.java	2009-07-08 09:58:18 +0000
+++ local/in/DHISMIDP/src/org/hispindia/mobile/Compressor.java	2009-08-17 07:44:47 +0000
@@ -1,10 +1,36 @@
 package org.hispindia.mobile;
 
-
-
 import java.io.IOException;
 import java.io.ByteArrayOutputStream;
 
+/**
+ * A Comment on Range Encoding:
+ *
+ * Range encoding is a data compression method defined by G. N. N. Martin
+ * in his 1979 paper, Range encoding: an algorithm for removing redundancy
+ * from a digitized message.
+ *
+ * Range encoding conceptually encodes all the symbols of the message into
+ * one number. The central concept behind range encoding is this: given a
+ * large-enough range of integers, and a probability estimation for the symbols,
+ * the initial range can easily be divided into sub-ranges whose sizes are
+ * proportional to the probability of the symbol they represent. Each symbol of
+ * the message can then be encoded in turn, by reducing the current range down
+ * to just that sub-range which corresponds to the next symbol to be encoded.
+ * The decoder must have the same probability estimation the encoder used,
+ * which can either be sent in advance, derived from already transferred data
+ * or be part of the compressor and decompressor.
+ *
+ * When all symbols have been encoded, merely identifying the sub-range is
+ * enough to communicate the entire message (presuming of course that the
+ * decoder is somehow notified when it has extracted the entire message).
+ * A single integer is actually sufficient to identify the sub-range, and it
+ * may not even be necessary to transmit the entire integer; if there is a
+ * sequence of digits such that every integer beginning with that prefix falls
+ * within the sub-range, then the prefix alone is all that's needed to identify
+ * the sub-range and thus transmit the message.
+ */
+
 public class Compressor {
 
     /* Tailored to int as 32bit signed */

=== added directory 'local/in/SMSListener/lib'
=== added file 'local/in/SMSListener/lib/comm.jar'
Binary files local/in/SMSListener/lib/comm.jar	1970-01-01 00:00:00 +0000 and local/in/SMSListener/lib/comm.jar	2009-08-17 07:44:47 +0000 differ
=== added file 'local/in/SMSListener/lib/commons-net-2.0.jar'
Binary files local/in/SMSListener/lib/commons-net-2.0.jar	1970-01-01 00:00:00 +0000 and local/in/SMSListener/lib/commons-net-2.0.jar	2009-08-17 07:44:47 +0000 differ
=== added file 'local/in/SMSListener/lib/log4j-1.2.15.jar'
Binary files local/in/SMSListener/lib/log4j-1.2.15.jar	1970-01-01 00:00:00 +0000 and local/in/SMSListener/lib/log4j-1.2.15.jar	2009-08-17 07:44:47 +0000 differ
=== added file 'local/in/SMSListener/lib/mail.jar'
Binary files local/in/SMSListener/lib/mail.jar	1970-01-01 00:00:00 +0000 and local/in/SMSListener/lib/mail.jar	2009-08-17 07:44:47 +0000 differ
=== added file 'local/in/SMSListener/lib/smslib-3.3.3.jar'
Binary files local/in/SMSListener/lib/smslib-3.3.3.jar	1970-01-01 00:00:00 +0000 and local/in/SMSListener/lib/smslib-3.3.3.jar	2009-08-17 07:44:47 +0000 differ
=== modified file 'local/in/SMSListener/nbproject/project.properties'
--- local/in/SMSListener/nbproject/project.properties	2009-08-17 06:20:39 +0000
+++ local/in/SMSListener/nbproject/project.properties	2009-08-17 07:44:47 +0000
@@ -1,5 +1,6 @@
-application.title=TestSMS
-application.vendor=sundeeps_adm
+application.desc=The Application to receive SMS from SCDRT mobile application and convert to xml which can be imported by DHIS2 Mobile Importing module
+application.title=SMS Listener
+application.vendor=HISP India
 build.classes.dir=${build.dir}/classes
 build.classes.excludes=**/*.java,**/*.form
 # This directory is removed when the project is cleaned:
@@ -21,18 +22,18 @@
 dist.jar=${dist.dir}/SMSListener.jar
 dist.javadoc.dir=${dist.dir}/javadoc
 excludes=
-file.reference.comm.jar=src/lib/comm.jar
-file.reference.commons-net-2.0.jar=src/lib/commons-net-2.0.jar
-file.reference.log4j-1.2.15.jar=src/lib/log4j-1.2.15.jar
-file.reference.mail.jar=src/lib/mail.jar
-file.reference.smslib-3.3.3.jar=src/lib/smslib-3.3.3.jar
+file.reference.comm.jar=lib/comm.jar
+file.reference.commons-net-2.0.jar=lib/commons-net-2.0.jar
+file.reference.log4j-1.2.15.jar=lib/log4j-1.2.15.jar
+file.reference.mail.jar=lib/mail.jar
+file.reference.smslib-3.3.3.jar=lib/smslib-3.3.3.jar
 includes=**
-jar.compress=false
+jar.compress=true
 javac.classpath=\
     ${file.reference.comm.jar}:\
     ${file.reference.commons-net-2.0.jar}:\
+    ${file.reference.log4j-1.2.15.jar}:\
     ${file.reference.mail.jar}:\
-    ${file.reference.log4j-1.2.15.jar}:\
     ${file.reference.smslib-3.3.3.jar}
 # Space-separated list of extra javac options
 javac.compilerargs=
@@ -55,6 +56,11 @@
 javadoc.use=true
 javadoc.version=false
 javadoc.windowtitle=
+jnlp.codebase.type=local
+jnlp.descriptor=application
+jnlp.enabled=false
+jnlp.offline-allowed=false
+jnlp.signed=false
 main.class=org.hispindia.smslistener.SMSListener
 manifest.file=manifest.mf
 meta.inf.dir=${src.dir}/META-INF

=== removed directory 'local/in/SMSListener/src/lib'
=== removed file 'local/in/SMSListener/src/lib/comm.jar'
Binary files local/in/SMSListener/src/lib/comm.jar	2009-07-08 09:58:18 +0000 and local/in/SMSListener/src/lib/comm.jar	1970-01-01 00:00:00 +0000 differ
=== removed file 'local/in/SMSListener/src/lib/commons-net-2.0.jar'
Binary files local/in/SMSListener/src/lib/commons-net-2.0.jar	2009-07-08 09:58:18 +0000 and local/in/SMSListener/src/lib/commons-net-2.0.jar	1970-01-01 00:00:00 +0000 differ
=== removed file 'local/in/SMSListener/src/lib/log4j-1.2.15.jar'
Binary files local/in/SMSListener/src/lib/log4j-1.2.15.jar	2009-07-08 09:58:18 +0000 and local/in/SMSListener/src/lib/log4j-1.2.15.jar	1970-01-01 00:00:00 +0000 differ
=== removed file 'local/in/SMSListener/src/lib/mail.jar'
Binary files local/in/SMSListener/src/lib/mail.jar	2009-07-08 09:58:18 +0000 and local/in/SMSListener/src/lib/mail.jar	1970-01-01 00:00:00 +0000 differ
=== removed file 'local/in/SMSListener/src/lib/smslib-3.3.3.jar'
Binary files local/in/SMSListener/src/lib/smslib-3.3.3.jar	2009-07-08 09:58:18 +0000 and local/in/SMSListener/src/lib/smslib-3.3.3.jar	1970-01-01 00:00:00 +0000 differ
=== modified file 'local/in/SMSListener/src/org/hispindia/smslistener/Compressor.java'
--- local/in/SMSListener/src/org/hispindia/smslistener/Compressor.java	2009-07-08 09:58:18 +0000
+++ local/in/SMSListener/src/org/hispindia/smslistener/Compressor.java	2009-08-17 07:44:47 +0000
@@ -3,6 +3,34 @@
 import java.io.IOException;
 import java.io.ByteArrayOutputStream;
 
+/**
+ * A Comment on Range Encoding:
+ *
+ * Range encoding is a data compression method defined by G. N. N. Martin
+ * in his 1979 paper, Range encoding: an algorithm for removing redundancy
+ * from a digitized message.
+ *
+ * Range encoding conceptually encodes all the symbols of the message into
+ * one number. The central concept behind range encoding is this: given a
+ * large-enough range of integers, and a probability estimation for the symbols,
+ * the initial range can easily be divided into sub-ranges whose sizes are
+ * proportional to the probability of the symbol they represent. Each symbol of
+ * the message can then be encoded in turn, by reducing the current range down
+ * to just that sub-range which corresponds to the next symbol to be encoded.
+ * The decoder must have the same probability estimation the encoder used,
+ * which can either be sent in advance, derived from already transferred data
+ * or be part of the compressor and decompressor.
+ *
+ * When all symbols have been encoded, merely identifying the sub-range is
+ * enough to communicate the entire message (presuming of course that the
+ * decoder is somehow notified when it has extracted the entire message).
+ * A single integer is actually sufficient to identify the sub-range, and it
+ * may not even be necessary to transmit the entire integer; if there is a
+ * sequence of digits such that every integer beginning with that prefix falls
+ * within the sub-range, then the prefix alone is all that's needed to identify
+ * the sub-range and thus transmit the message.
+ */
+
 public class Compressor {
 
     /* Tailored to int as 32bit signed */

